.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`registration`
===========================
.. automodule:: skimage.registration

.. currentmodule:: skimage.registration
.. autosummary::

   skimage.registration.optical_flow_tvl1
   skimage.registration.phase_cross_correlation



optical_flow_tvl1
-----------------

.. autofunction:: skimage.registration.optical_flow_tvl1


.. include:: skimage.registration.optical_flow_tvl1.examples

phase_cross_correlation
-----------------------

.. autofunction:: skimage.registration.phase_cross_correlation


.. include:: skimage.registration.phase_cross_correlation.examples

